# Autogenerated by nbdev

d = { 'settings': { 'audience': 'Developers',
                'author': 'Joao Paulo Nogueira',
                'author_email': 'joaopcnogueira@gmail.com',
                'branch': 'main',
                'copyright': 'Put your copyright info here',
                'custom_sidebar': 'False',
                'description': 'Labdata Hello Python Package',
                'doc_baseurl': '/hello_labdata_jp/',
                'doc_host': 'https://joaopcnogueira.github.io',
                'doc_path': '_docs',
                'git_url': 'https://github.com/joaopcnogueira/hello-labdata-jp/',
                'host': 'github',
                'keywords': 'nbdev',
                'language': 'English',
                'lib_name': 'hello_labdata_jp',
                'lib_path': 'hello_labdata_jp',
                'license': 'apache2',
                'min_python': '3.9',
                'nbs_path': '.',
                'recursive': 'False',
                'repo': 'hello-labdata-jp',
                'status': '2',
                'title': 'hello_labdata_jp',
                'tst_flags': 'notest',
                'user': 'joaopcnogueira',
                'version': '0.0.1'},
  'syms': { 'hello_labdata_jp.greetings': {'hello_labdata_jp.greetings.hello': 'https://joaopcnogueira.github.io/hello_labdata_jp/greetings.html#hello'},
            'hello_labdata_jp.jokes': { 'hello_labdata_jp.jokes.qual_time_nao_tem_mundial': 'https://joaopcnogueira.github.io/hello_labdata_jp/jokes.html#qual_time_nao_tem_mundial'}}}